Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(460)

Unified Diff: chrome/browser/storage/durable_storage_permission_infobar_delegate.h

Issue 1164073005: Allow script to request durable storage permission (chrome side) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix conflicts after midi constant permission landed Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage/durable_storage_permission_infobar_delegate.h
diff --git a/chrome/browser/media/midi_permission_infobar_delegate.h b/chrome/browser/storage/durable_storage_permission_infobar_delegate.h
similarity index 50%
copy from chrome/browser/media/midi_permission_infobar_delegate.h
copy to chrome/browser/storage/durable_storage_permission_infobar_delegate.h
index e10d973cea1aa1d72a547b50f0f1d109b59c9080..d8f54f3e761f83c55431da1b33832d4d679be633 100644
--- a/chrome/browser/media/midi_permission_infobar_delegate.h
+++ b/chrome/browser/storage/durable_storage_permission_infobar_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_MEDIA_MIDI_PERMISSION_INFOBAR_DELEGATE_H_
-#define CHROME_BROWSER_MEDIA_MIDI_PERMISSION_INFOBAR_DELEGATE_H_
+#ifndef CHROME_BROWSER_STORAGE_DURABLE_STORAGE_PERMISSION_INFOBAR_DELEGATE_H_
+#define CHROME_BROWSER_STORAGE_DURABLE_STORAGE_PERMISSION_INFOBAR_DELEGATE_H_
#include <string>
#include "chrome/browser/permissions/permission_infobar_delegate.h"
@@ -13,12 +13,11 @@ class GURL;
class PermissionQueueController;
class InfoBarService;
-// MidiPermissionInfoBarDelegates are created by the
-// MidiPermissionContext to control the display and handling of MIDI permission
-// infobars to the user.
-class MidiPermissionInfoBarDelegate : public PermissionInfobarDelegate {
+class DurableStoragePermissionInfoBarDelegate
+ : public PermissionInfobarDelegate {
public:
// Creates a MIDI permission infobar and delegate and adds the infobar to
// |infobar_service|. Returns the infobar if it was successfully added.
static infobars::InfoBar* Create(InfoBarService* infobar_service,
PermissionQueueController* controller,
@@ -28,21 +27,19 @@ class MidiPermissionInfoBarDelegate : public PermissionInfobarDelegate {
ContentSettingsType type);
private:
- MidiPermissionInfoBarDelegate(PermissionQueueController* controller,
- const PermissionRequestID& id,
- const GURL& requesting_frame,
- const std::string& display_languages,
- ContentSettingsType type);
- ~MidiPermissionInfoBarDelegate() override;
-
- // ConfirmInfoBarDelegate:
- int GetIconID() const override;
+ DurableStoragePermissionInfoBarDelegate(PermissionQueueController* controller,
+ const PermissionRequestID& id,
+ const GURL& requesting_frame,
+ const std::string& display_languages,
+ ContentSettingsType type);
+ ~DurableStoragePermissionInfoBarDelegate() override = default;
+
base::string16 GetMessageText() const override;
GURL requesting_frame_;
std::string display_languages_;
- DISALLOW_COPY_AND_ASSIGN(MidiPermissionInfoBarDelegate);
+ DISALLOW_COPY_AND_ASSIGN(DurableStoragePermissionInfoBarDelegate);
};
-#endif // CHROME_BROWSER_MEDIA_MIDI_PERMISSION_INFOBAR_DELEGATE_H_
+#endif // CHROME_BROWSER_STORAGE_DURABLE_STORAGE_PERMISSION_INFOBAR_DELEGATE_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -13,12 +13,11 @@ class GURL;
public:
- // Creates a MIDI permission infobar and delegate and adds the infobar to
+ // Creates a DurableStorage permission infobar and delegate and adds the
+ // infobar to
// |infobar_service|. Returns the infobar if it was successfully added.
static infobars::InfoBar* Create(InfoBarService* infobar_service,